@@ -42,7 +42,10 @@
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from _version import __version__
+try:
+  from . import _version
+except:
+    from teUtils import _version
 
 __version__ = _version.__version__
 
